## Initial table using pg_pathman

#!/bin/bash

WORK_PATH=/data/PRD/postgres/11.5/home/postgres/planning_time_test
DB_CONN=127.0.0.1
DB_USER=myapp
DB_PORT=1234
DB_DBNAME=asgard
NUM_OF_PARTITIONS=$1


cd ${WORK_PATH}
echo "TESTING START using pg_pathman ..."
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "DROP TABLE IF EXISTS myapp.my_testtable cascade"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "CREATE TABLE myapp.my_testtable (id bigint NOT NULL , smid text NOT NULL, umid bigint NOT NULL, fromcol text NOT NULL, fromcolindex text DEFAULT ''::text NOT NULL, mycolumn1 text NOT NULL, ctype smallint NOT NULL, clert text DEFAULT ''::text NOT NULL,  status smallint DEFAULT 0, updatetm timestamp without time zone NOT NULL)"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "select create_hash_partitions('my_testtable'::regclass,'mycolumn1', ${NUM_OF_PARTITIONS}, false)"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "ALTER TABLE myapp.my_testtable add CONSTRAINT my_testtable_pkey  PRIMARY KEY (id)"

## Deal with sequence
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "CREATE SEQUENCE myapp.my_testtable_p${NUM_OF_PARTITIONS}_id_seq START WITH 1 INCREMENT BY 1 NO MINVALUE  NO MAXVALUE CACHE 30"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "ALTER TABLE myapp.my_testtable_p${NUM_OF_PARTITIONS}_id_seq OWNER TO myapp"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "ALTER SEQUENCE myapp.my_testtable_p${NUM_OF_PARTITIONS}_id_seq OWNED BY myapp.my_testtable.id"
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -p ${DB_PORT} -o ${WORK_PATH}/tmp.txt -c "ALTER TABLE  myapp.my_testtable ALTER COLUMN id SET DEFAULT nextval('myapp.my_testtable_p${NUM_OF_PARTITIONS}_id_seq'::regclass)"

## Deal with indexes
echo "CREATING ${NUM_OF_PARTITIONS} OF PARTITIONS INDEX, PLEASE WAIT..."
for((j=0;j<=${NUM_OF_PARTITIONS}-1;j++));
 do
   psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -o ${WORK_PATH}/tmp.txt -c "create index concurrently my_testtable_${j}_mycolumn1_fromcol_umid_updatetm_idx on my_testtable_${j}(mycolumn1, fromcol,umid,updatetm)"
   psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -o ${WORK_PATH}/tmp.txt -c "create index concurrently my_testtable_${j}_mycolumn1_clert_umid_updatetm_idx   on my_testtable_${j}(mycolumn1, clert,umid,updatetm)"
   psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -o ${WORK_PATH}/tmp.txt -c "create index concurrently my_testtable_${j}_updatetm_idx                       on my_testtable_${j}(updatetm)"
   psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER} -o ${WORK_PATH}/tmp.txt -c "create index concurrently my_testtable_${j}_umid_idx                           on my_testtable_${j}(umid)"
 done

rm -rf ${WORK_PATH}/tmp.txt

echo " ==> FIRST PLANING TIME TEST(1/2)."
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER}  -c "explain (analyze,buffers,verbose) select umid,smid from myapp.my_testtable WHERE  mycolumn1 = 'gogo.giraffe' and umid > 65124397 order by umid desc limit 1 offset 6000"

echo " ==> SLEEP 3 SECONDS."
sleep 3

echo " ==> SECOND PLANING TIME TEST(2/2)."
psql -h ${DB_CONN} -d ${DB_DBNAME} -U ${DB_USER}  -c "explain (analyze,buffers,verbose) select umid,smid from myapp.my_testtable WHERE  mycolumn1 = 'gogo.giraffe' and umid > 65124397 order by umid desc limit 1 offset 6000"

echo "TESTING END ..."
echo " "
echo " "